import React, { useState, useEffect } from 'react'
import { translate } from 'cozy-ui/react/I18n'
import {
  ChallengeType,
  UserChallenge,
  EcogestureType,
} from 'services/dataChallengeContracts'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import ChevronGrey from 'assets/icons/ico/chevron-right-grey.svg'
import ChevronBlue from 'assets/icons/ico/chevron-right-blue.svg'
import ChevronDarkBlue from 'assets/icons/ico/chevron-right-darkblue.svg'
import LockedChallengeIcon from 'assets/png-badges/locked.png'
import AvailableChallengeIcon from 'assets/png-badges/available.png'
import OngoingChallengeIcon from 'assets/png-badges/ongoing.png'
import DefaultChallengeIcon from 'assets/png-badges/default.png'
import { NavLink } from 'react-router-dom'

interface ChallengeListItemProps {
  challenge: ChallengeType
  userChallenge?: UserChallenge
  handleClick?: (challenge: ChallengeType) => void
  t: Function
  challengeState?: string
  ecogestures?: EcogestureType[]
}

const ChallengeListItem: React.FC<ChallengeListItemProps> = ({
  challenge,
  userChallenge,
  t,
  challengeState,
}: ChallengeListItemProps) => {
  const [badgeIcon, setBadgeIcon] = useState<any | null>(null)

  async function importRightBadge(id: string, badgeStatus: number) {
    // Les svg doivent être au format idchallenge-badgestate.svg
    const importedBadge = await import(
      /* webpackMode: "eager" */ `assets/png-badges/${id}-${badgeStatus}.png`
    )
    setBadgeIcon(importedBadge.default)
  }

  const defineBadge = () => {
    return challengeState === 'locked'
      ? LockedChallengeIcon
      : challengeState === 'available'
      ? AvailableChallengeIcon
      : challengeState === 'ongoing'
      ? OngoingChallengeIcon
      : challengeState === 'finished'
      ? badgeIcon
      : DefaultChallengeIcon
  }

  useEffect(() => {
    if (challenge && userChallenge) {
      importRightBadge(
        challenge.id,
        userChallenge.badge ? userChallenge.badge : 0
      )
    }
  }, [])

  return (
    <NavLink
      className="cli-link"
      to={{
        pathname: `challenges/${challengeState}`,
        state: { challenge: userChallenge ? userChallenge : challenge },
      }}
    >
      <div className={`cli cli-${challengeState}`}>
        <div className="cli-left">
          <div className="cli-content">
            <img
              className="cli-content-icon"
              src={defineBadge() ? defineBadge() : DefaultChallengeIcon}
              width={62}
            ></img>
            <div className={`cli-content-title`}>
              {challengeState === 'available' && (
                <div className={`subtitle-${challengeState} text-16-normal`}>
                  {t('CHALLENGE.NEW_CHALLENGE')}
                </div>
              )}
              {challengeState === 'ongoing' && (
                <div className={`subtitle-${challengeState} text-16-normal`}>
                  {t('CHALLENGE.ONGOING_CHALLENGE')}
                </div>
              )}
              {challengeState === 'finished' && (
                <div className={`subtitle-${challengeState} text-16-normal`}>
                  {userChallenge
                    ? userChallenge.endingDate
                        .setLocale('fr-FR')
                        .toLocaleString()
                    : t('CHALLENGE.ENDINGDATE_UNDEFINED')}
                </div>
              )}
              <div className={`title-${challengeState} text-18-bold`}>
                {!challenge.title
                  ? t('CHALLENGE.NO_CHALLENGE')
                  : challenge.title}
              </div>
            </div>
          </div>
        </div>
        <div className={`cli-right cli-right-${challengeState}`}>
          {challengeState === 'available' ? (
            <StyledIcon icon={ChevronDarkBlue} size={18} />
          ) : challengeState === 'ongoing' ? (
            <StyledIcon icon={ChevronBlue} size={18} />
          ) : (
            <StyledIcon icon={ChevronGrey} size={18} />
          )}
        </div>
      </div>
    </NavLink>
  )
}

export default translate()(ChallengeListItem)
